| cprocess | R Documentation |
cprocess plots the cumulative number of events (the counting
process) over time for each vector in the list. One or both of
times and events can be supplied.
cprocess(times=NULL, events=NULL, number=FALSE, lty=NULL, xlim=NULL,
ylim=NULL, xlab="Time", ylab="Counts", ...)
times |
Vector of times between events, a list of such
vectors, or a |
events |
Vector of counts of events, a list of such vectors, or a
|
number |
If TRUE, the counting processes are numbered consecutively on the graph. |
ylab |
Plotting control options. |
xlab |
Plotting control options. |
xlim |
Plotting control options. |
ylim |
Plotting control options. |
lty |
Plotting control options. |
... |
Plotting control options. |
J.K. Lindsey
read.list, rmna.
times <- rgamma(20,2,scale=4)
cprocess(times)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.