hcauchy: Log Hazard Function for a Cauchy Process

View source: R/intensity.r

hcauchyR Documentation

Log Hazard Function for a Cauchy Process

Description

Log Hazard Function for a Cauchy Process

Usage

hcauchy(y, m, s)

Arguments

y

Vector of times.

m

Location parameter.

s

Dispersion parameter.

Value

hcauchy returns the log hazard function for a Cauchy process with the given parameter values.

Author(s)

J.K. Lindsey

See Also

hboxcox, hburr, hexp, hgextval, hgamma, hggamma, hhjorth, hinvgauss, hlaplace, hlnorm, hlogis, hglogis, hnorm, hstudent, hweibull, hgweibull.

Examples

hcauchy(1:10, 3, 2)

event documentation built on Feb. 16, 2026, 5:08 p.m.