hexp: Log Hazard Function for a Poisson Process

View source: R/intensity.r

hexpR Documentation

Log Hazard Function for a Poisson Process

Description

Log Hazard Function for a Poisson Process

Usage

hexp(y, rate)

Arguments

y

Vector of times.

rate

Vector of rates.

Value

hexp returns the log hazard function for a Poisson process with the given parameter value.

Author(s)

J.K. Lindsey

See Also

hboxcox, hburr, hexp, hgextval, hgamma, hggamma, hhjorth, hinvgauss, hlaplace, hlnorm, hlogis, hglogis, hnorm, hstudent, hweibull, hgweibull.

Examples

hexp(1:10, 3)

event documentation built on Feb. 16, 2026, 5:08 p.m.