hlaplace: Log Hazard Function for a Laplace Process

View source: R/intensity.r

hlaplaceR Documentation

Log Hazard Function for a Laplace Process

Description

These functions provide information about the Laplace distribution with location parameter equal to m and dispersion equal to s: log hazard. (See 'rmutil' for the d/p/q/r boxcox functions density, cumulative distribution, quantiles, and random generation).

The Laplace distribution has density

f(y) = \frac{\exp(-abs(y-\mu)/\sigma)}{(2\sigma)}

where \mu is the location parameter of the distribution and \sigma is the dispersion.

Usage

hlaplace(y, m=0, s=1)

Arguments

y

vector of responses.

m

vector of location parameters.

s

vector of dispersion parameters.

Author(s)

J.K. Lindsey

See Also

dexp for the exponential distribution and dcauchy for the Cauchy distribution.

Examples

hlaplace(5, 2, 1)

event documentation built on Feb. 16, 2026, 5:08 p.m.