hlnorm: Log Hazard Function for a Log Normal Process

View source: R/intensity.r

hlnormR Documentation

Log Hazard Function for a Log Normal Process

Description

Log Hazard Function for a Log Normal Process

Usage

hlnorm(y, m, s)

Arguments

y

Vector of times.

m

Mean parameter.

s

Variance parameter.

Value

hlnorm returns the log hazard function for a log normal process with the given parameter values.

Author(s)

J.K. Lindsey

See Also

hboxcox, hburr, hexp, hgextval, hcauchy, hgamma, hggamma, hhjorth, hinvgauss, hlaplace, hlogis, hglogis, hnorm, hstudent, hweibull, hgweibull.

Examples

hlnorm(1:10, 3, 2)

event documentation built on Feb. 16, 2026, 5:08 p.m.