hlogis: Log Hazard Function for a Logistic Process

View source: R/intensity.r

hlogisR Documentation

Log Hazard Function for a Logistic Process

Description

Log Hazard Function for a Logistic Process

Usage

hlogis(y, m, s)

Arguments

y

Vector of times.

m

Location parameter.

s

Scale parameter.

Value

hlogis returns the log hazard function for a logistic process with the given parameter values.

Author(s)

J.K. Lindsey

See Also

hboxcox, hburr, hexp, hgextval, hcauchy, hgamma, hggamma, hhjorth, hinvgauss, hlaplace, hlnorm, hglogis, hnorm, hstudent, hweibull, hgweibull.

Examples

hlogis(1:10, 3, 2)

event documentation built on Feb. 16, 2026, 5:08 p.m.