hnorm: Log Hazard Function for a Normal Process

View source: R/intensity.r

hnormR Documentation

Log Hazard Function for a Normal Process

Description

Log Hazard Function for a Normal Process

Usage

hnorm(y, m, s)

Arguments

y

Vector of times.

m

Mean parameter.

s

Variance parameter.

Value

hnorm returns the log hazard function for a normal process with the given parameter values.

Author(s)

J.K. Lindsey

See Also

hboxcox, hburr, hexp, hgextval, hcauchy, hgamma, hggamma, hhjorth, hinvgauss, hlaplace, hlogis, hglogis, hlnorm, hstudent, hweibull, hgweibull.

Examples

hnorm(1:10, 3, 2)

event documentation built on Feb. 16, 2026, 5:08 p.m.