| hpareto | R Documentation |
These functions provide information about the Pareto distribution
with location parameter equal to m and dispersion equal to
s: log hazard.
(See 'rmutil' for the d/p/q/r boxcox functions density,
cumulative distribution, quantiles, and random generation).
The Pareto distribution has density
f(y) = \frac{\sigma }{\mu (\sigma-1)(1 + y/(\mu (\sigma-1)))^{\sigma+1}}
where \mu is the mean parameter of the distribution and
\sigma is the dispersion.
This distribution can be obtained as a mixture distribution from the exponential distribution using a gamma mixing distribution.
hpareto(y, m, s)
y |
vector of responses. |
m |
vector of location parameters. |
s |
vector of dispersion parameters. |
J.K. Lindsey
dexp for the exponential distribution.
hpareto(5, 2, 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.