| hskewlaplace | R Documentation |
These functions provide information about the skew Laplace distribution
with location parameter equal to m, dispersion equal to
s, and skew equal to f: log hazard.
(See 'rmutil' for the d/p/q/r boxcox functions density,
cumulative distribution, quantiles, and random generation).
For f=1, this is an ordinary (symmetric) Laplace distribution.
The skew Laplace distribution has density
f(y) = \frac{\nu\exp(-\nu(y-\mu)/\sigma)}{(1+\nu^2)\sigma}
if y\ge\mu and else
f(y) = \frac{\nu\exp((y-\mu)/(\nu\sigma))}{(1+\nu^2)\sigma}
where \mu is the location parameter of the distribution,
\sigma is the dispersion, and \nu is the skew.
The mean is given by \mu+\frac{\sigma(1-\nu^2)}{\sqrt{2}\nu}
and the variance by \frac{\sigma^2(1+\nu^4)}{2\nu^2}.
Note that this parametrization of the skew (family) parameter is different than that used for the multivariate skew Laplace distribution in 'growth::elliptic'.
hskewlaplace(y, m=0, s=1, f=1)
y |
vector of responses. |
m |
vector of location parameters. |
s |
vector of dispersion parameters. |
f |
vector of skew parameters. |
J.K. Lindsey
dexp for the exponential distribution,
dcauchy for the Cauchy distribution, and
dlaplace for the Laplace distribution.
hskewlaplace(5, 2, 1, 0.5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.