hstudent: Log Hazard Function for a Student t Process

View source: R/intensity.r

hstudentR Documentation

Log Hazard Function for a Student t Process

Description

Log Hazard Function for a Student t Process

Usage

hstudent(y, m, s, f)

Arguments

y

Vector of times.

m

Location parameter.

s

Scale parameter.

f

Degrees of freedom.

Value

hstudent returns the log hazard function for a Student t process with the given parameter values.

Author(s)

J.K. Lindsey

See Also

hboxcox, hburr, hexp, hgextval, hcauchy, hgamma, hggamma, hhjorth, hinvgauss, hlaplace, hlogis, hglogis, hnorm, hnorm, hweibull, hgweibull.

Examples

hstudent(1:10, 3, 2, 5)

event documentation built on Feb. 16, 2026, 5:08 p.m.