hweibull: Log Hazard Function for a Weibull Process

View source: R/intensity.r

hweibullR Documentation

Log Hazard Function for a Weibull Process

Description

Log Hazard Function for a Weibull Process

Usage

hweibull(y, s, m)

Arguments

y

Vector of times.

s

Shape parameter.

m

Scale parameter.

Value

hweibull returns the log hazard function for a Weibull process with the given parameter values.

Author(s)

J.K. Lindsey

See Also

hboxcox, hburr, hexp, hgextval, hcauchy, hgamma, hggamma, hhjorth, hinvgauss, hlaplace, hlogis, hglogis, hlnorm, hnorm, hstudent, hgweibull.

Examples

hweibull(1:10, 1.5, 2)

event documentation built on Feb. 16, 2026, 5:08 p.m.