| ident | R Documentation |
ident creates a vector of length sum(y) by repeating the
values of individual identifiers for the times for use with
ehr.
ident(y, id)
y |
Vector of times. |
id |
Vector of corresponding individual identifiers for who had which sequence of times. |
ident creates a vector of length sum(y) by repeating the
values of individual identifiers for the times for use with
ehr.
J.K. Lindsey
bp, ehr,
pp, tccov,
tpast, ttime,
tvcov.
y <- c(5,3,2,4)
i <- c(1,1,2,2)
id <- ident(y, i)
id
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.