| pp | R Documentation |
pp creates a vector of length sum(y) of zeroes with a one
at the end of each uncensored time interval for use with
ehr.
pp(y, censor=1)
y |
Vector of times. |
censor |
Vector of censoring indicators. |
pp creates a vector of length sum(y) of zeroes with a one
at the end of each uncensored time interval for use with
ehr.
J.K. Lindsey
bp, ehr,
ident, tccov,
tpast, ttime,
tvcov.
y <- c(5,3,2,4)
py <- pp(y)
py
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.