| hlaplace | R Documentation |
These functions provide information about the Laplace distribution
with location parameter equal to m and dispersion equal to
s: log hazard.
(See 'rmutil' for the d/p/q/r boxcox functions density,
cumulative distribution, quantiles, and random generation).
The Laplace distribution has density
f(y) = \frac{\exp(-abs(y-\mu)/\sigma)}{(2\sigma)}
where \mu is the location parameter of the distribution and
\sigma is the dispersion.
hlaplace(y, m=0, s=1)
y |
vector of responses. |
m |
vector of location parameters. |
s |
vector of dispersion parameters. |
J.K. Lindsey
dexp for the exponential distribution and
dcauchy for the Cauchy distribution.
hlaplace(5, 2, 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.